import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    name: 'login',
    component: () => import('@/views/login/index')
    // hidden: true
  },
  {
    path: '/register',
    component: () => import('@/views/register/index')
    // hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  // {
  //   path: '/',
  //   component: Layout,
  //   redirect: '/dashboard',
  //   children: [{
  //     path: 'dashboard',
  //     name: 'Dashboard',
  //     component: () => import('@/views/dashboard/index'),
  //     meta: { title: '合同列表', icon: 'dashboard' }
  //   }]
  // },
  {
    path: '/',
    component: Layout,
    redirect: '/contracts',
    name: 'Example',
    meta: { title: '合同列表', icon: 'el-icon-s-order' },
    children: [
      {
        path: 'list',
        name: 'contracts-list',
        component: () => import('@/views/contracts/list'),
        meta: { title: '合同列表', icon: 'el-icon-s-order' },
        hidden: true
      },
      {
        path: 'contracts',
        name: 'contracts',
        component: () => import('@/views/contracts/index'),
        meta: { title: '合同列表', icon: 'el-icon-s-order' }

      // hidden:true,
      },
      {
        path: '/detail',
        name: 'detail',
        component: () => import('@/views/contracts/detail'),
        meta: { title: '合同详情' },
        hidden: true
      },
      // {
      //   path: 'contracts/addcontract',
      //   name: 'addcontract',
      //  component: () => import('@/views/contracts/addcontract'),
      //  meta: { title: '上传合同' },
      //  hidden:true
      // },
      {
        path: 'contracts/addnewbill',
        name: 'addnewbill',
        component: () => import('@/views/contracts/addnewbill'),
        meta: { title: '新增汇票' },
        hidden: true
      },
      {
        path: 'contracts/billDetail',
        name: 'billDetail',
        component: () => import('@/views/contracts/billDetail'),
        meta: { title: '汇票详情' },
        hidden: true
      },
      {
        path: 'contracts/addcontract',
        name: 'addcontract',
        component: () => import('@/views/contracts/new_file'),
        meta: { title: '新增合同' },
        hidden: true
      }
    ]
  },

  {
    path: '/table',
    component: Layout,
    redirect: '/table',
    name: 'Example',
    meta: { title: '承兑人列表', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'table',
        name: 'Table',
        component: () => import('@/views/table/index'),
        meta: { title: '承兑人列表', icon: 'el-icon-s-help' }
      },
      {
        path: '/table/addAcceptor',
        name: 'Table',
        component: () => import('@/views/table/addAcceptor'),
        meta: { title: '新增承兑人' },
        hidden: true
      },
      {
        path: 'table/detail',
        name: 'Table',
        component: () => import('@/views/table/detail'),
        meta: { title: '承兑人详情' },
        hidden: true
      }
    ]
  },

  {
    path: '/form',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'Form',
        component: () => import('@/views/form/index'),
        meta: { title: '出票人列表', icon: 'form' }
      },
      {
        path: '/form/addTicketdrawer',
        name: 'addTicketdrawer',
        component: () => import('@/views/form/addTicketdrawer'),
        meta: { title: '新增出票人' },
        hidden: true
      },
      {
        path: '/form/detail',
        name: 'detail',
        component: () => import('@/views/form/detail'),
        meta: { title: '出票人详情' },
        hidden: true
      }
    ]
  },
  {
    path: '/delivery',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'delivery',
        component: () => import('@/views/delivery/index'),
        meta: { title: '供应商账号', icon: 'el-icon-s-promotion' }
      },
      {
        path: '/edit',
        name: 'edit',
        component: () => import('@/views/delivery/edit'),
        meta: { title: '编辑' },
        hidden: true
      }
    ]
  },
  // {
  //   path: '/nested',
  //   component: Layout,
  //   redirect: '/nested/menu1',
  //   name: 'Settlement',
  //   meta: {
  //     title: '供应商账号',
  //     icon: 'nested'
  //   },
  //   children: [
  //     {
  //       path: 'menu1',
  //       component: () => import('@/views/nested/menu1/index'), // Parent router-view
  //       name: 'Menu1',
  //       meta: { title: 'Menu1' },
  //       children: [
  //         {
  //           path: 'menu1-1',
  //           component: () => import('@/views/nested/menu1/menu1-1'),
  //           name: 'Menu1-1',
  //           meta: { title: 'Menu1-1' }
  //         },
  //         {
  //           path: 'menu1-2',
  //           component: () => import('@/views/nested/menu1/menu1-2'),
  //           name: 'Menu1-2',
  //           meta: { title: 'Menu1-2' },
  //           children: [
  //             {
  //               path: 'menu1-2-1',
  //               component: () => import('@/views/nested/menu1/menu1-2/menu1-2-1'),
  //               name: 'Menu1-2-1',
  //               meta: { title: 'Menu1-2-1' }
  //             },
  //             {
  //               path: 'menu1-2-2',
  //               component: () => import('@/views/nested/menu1/menu1-2/menu1-2-2'),
  //               name: 'Menu1-2-2',
  //               meta: { title: 'Menu1-2-2' }
  //             }
  //           ]
  //         },
  //         {
  //           path: 'menu1-3',
  //           component: () => import('@/views/nested/menu1/menu1-3'),
  //           name: 'Menu1-3',
  //           meta: { title: 'Menu1-3' }
  //         }
  //       ]
  //     },
  //     {
  //       path: 'menu2',
  //       component: () => import('@/views/nested/menu2/index'),
  //       name: 'Menu2',
  //       meta: { title: 'menu2' }
  //     }
  //   ]
  // },

  {
    path: '/shipments',
    component: Layout,
    children: [
      {
        path: '/shipments/index',
        name: 'shipments',
        component: () => import('@/views/shipments/index'),
        meta: { title: '报表统计', icon: 'el-icon-s-marketing' }
      },
      {
        path: '/shipments1',
        name: 'shipments1',
        component: () => import('@/views/shipments/shipments1'),
        meta: { title: '出票人分类报表' },
        hidden: true
      },
      {
        path: '/shipments2',
        name: 'shipments2',
        component: () => import('@/views/shipments/shipments2'),
        meta: { title: '合同统计列表' },
        hidden: true
      },
      {
        path: '/shipments3',
        name: 'shipments3',
        component: () => import('@/views/shipments/shipments3'),
        meta: { title: '供应商统计列表' },
        hidden: true
      }

    ]
  },
  {
    path: '/management',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'management',
        component: () => import('@/views/management/index'),
        meta: { title: '业务管理员', icon: 'el-icon-s-management' }
      }
    ]
  },
  {
    path: '/sucuirtyaudit',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'sucuirtyaudit',
        component: () => import('@/views/sucuirtyaudit/index'),
        meta: { title: '安全审计', icon: 'el-icon-s-check' }
      },
      {
        path: '/annexList',
        name: 'annexList',
        component: () => import('@/views/sucuirtyaudit/annexList'),
        meta: { title: '附件列表' },
        hidden: true
      },
      {
        path: '/logdetail',
        name: 'detail',
        component: () => import('@/views/sucuirtyaudit/detail'),
        meta: { title: '审计日志详情' },
        hidden: true
      }
    ]
  },
  {
    path: '/databackup',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'databackup',
        component: () => import('@/views/databackup/index'),
        meta: { title: '数据备份', icon: 'el-icon-upload' }
      }
    ]
  },
  {
    path: '/mine',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'mine',
        component: () => import('@/views/mine/index'),
        meta: { title: '个人资料', icon: 'el-icon-s-custom' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
